Attribute VB_Name = "WindowHandle"
' Nockylock - a program to block keyboard and mouse input
' Copyright (C) Gluegood Software

' This program is free software; you can redistribute it and/or
' modify it under the terms of the GNU General Public License
' as published by the Free Software Foundation; either version 2
' of the License, or (at your option) any later version.

' This program is distributed in the hope that it will be useful,
' but WITHOUT ANY WARRANTY; without even the implied warranty of
' MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
' GNU General Public License for more details.

' You should have received a copy of the GNU General Public License
' along with this program; if not, write to the Free Software
' Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
Option Explicit

Private Declare Function GetClassName Lib "user32" Alias "GetClassNameA" (ByVal hWnd As Long, ByVal lpClassName As String, ByVal nMaxCount As Long) As Long
Private Declare Function GetWindowText Lib "user32" Alias "GetWindowTextA" (ByVal hWnd As Long, ByVal lpString As String, ByVal cch As Long) As Long
Private Declare Function EnumWindows Lib "user32" (ByVal lpEnumFunc As Long, ByVal lParam As Long) As Long
Private Declare Function GetWindowThreadProcessId Lib "user32" (ByVal hWnd As Long, lpdwProcessId As Long) As Long
Private Declare Function SetWindowPos Lib "user32" (ByVal hWnd _
                    As Long, ByVal hWndInsertAfter As Long, _
                    ByVal x As Long, ByVal y As Long, _
                    ByVal cx As Long, ByVal cy As Long, ByVal _
                    wFlags As Long) As Long


Const SWP_NOMOVE = &H2
Const SWP_NOSIZE = &H1
Const HWND_TOPMOST = -1
Const HWND_NOTOPMOST = -2
Const SWP_NOACTIVATE = &H10
Const SWP_SHOWWINDOW = &H40


'Window Postion Enum
Public Enum enWindowPos
    OnTop = 0
    Normal = 1
End Enum
Private msWindowNameFind        As String
Private mlWindowFindThreadID    As Long
Private mlWindowFindProcessID   As Long
Private mlWindowHandle          As Long

Public Function EnumWinProc(ByVal lhWnd As Long, ByVal lParam As Long) As Long
    ' Enumerate all Desktop Windows
    On Error GoTo EnumWinProc_Error
    
    EnumWinProc = False
    
    Dim retVal As Long, ProcessID As Long, ThreadID As Long
    Dim WinClassBuf As String * 255, WinTitleBuf As String * 255
    Dim WinClass As String, WinTitle As String
    
    retVal = GetClassName(lhWnd, WinClassBuf, 255)
    WinClass = StripNulls(WinClassBuf)  ' remove extra Nulls & spaces
    retVal = GetWindowText(lhWnd, WinTitleBuf, 255)
    WinTitle = StripNulls(WinTitleBuf)
    ThreadID = GetWindowThreadProcessId(lhWnd, ProcessID)

    If Len(msWindowNameFind) > 0 Then
        ' Just Window Name
        If Left$(WinTitle, Len(msWindowNameFind)) = msWindowNameFind Then
            mlWindowHandle = lhWnd
        End If
        
    ElseIf mlWindowFindThreadID > 0 Then
        ' ProcessID and ThreadID
        If ThreadID = mlWindowFindThreadID And ProcessID = mlWindowFindProcessID Then
            mlWindowHandle = lhWnd
        End If
    
    ElseIf mlWindowFindProcessID > 0 Then
        ' Process ID find only
        If ProcessID = mlWindowFindProcessID Then
            mlWindowHandle = lhWnd
        End If
    End If

    EnumWinProc = True
    Exit Function

EnumWinProc_Error:
    Err.Clear
    EnumWinProc = False
    
End Function


Private Function StripNulls(OriginalStr As String) As String
    On Error Resume Next
    
   ' This removes the extra Nulls so String comparisons will work
   If (InStr(OriginalStr, Chr(0)) > 0) Then
      OriginalStr = Left(OriginalStr, InStr(OriginalStr, Chr(0)) - 1)
   End If
   StripNulls = OriginalStr
   
End Function


Public Function FindWindowHandleFromName(sWindowNameFind As String) As Long
    ' Pass the Window caption to Find and it returns the Full Window Caption
    On Error GoTo FindWindowCaptionFromName_Error
    
    Dim lRet As Long
    Dim lParam As Long
       
    'enumerate the list
    lRet = EnumWindows(AddressOf EnumWinProc, lParam)
    
    FindWindowHandleFromName = mlWindowHandle
    
    Exit Function
    
FindWindowCaptionFromName_Error:
    Err.Clear
    FindWindowHandleFromName = vbNullString
    
End Function


Public Function SetWindowOrder(ByVal hWnd As Long, _
                Optional Position As enWindowPos = OnTop)

Dim retVal As Long


'Set the forms position
Select Case Position
    Case enWindowPos.OnTop
        'Place form to stay on top
        retVal = SetWindowPos(hWnd, HWND_TOPMOST, _
                                0, 0, 0, 0, SWP_NOMOVE + SWP_NOSIZE)
    Case enWindowPos.Normal
        'Set the form back to normal
        retVal = SetWindowPos(hWnd, HWND_NOTOPMOST, _
                                0, 0, 0, 0, SWP_NOMOVE + SWP_NOSIZE)
End Select


'Return True if successful
SetWindowOrder = IIf(retVal = 0, False, True)


End Function

